@@ -7,7 +7,7 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/anchore/grype/grype/db"
-	grypeDB "github.com/anchore/grype/grype/db/v3"
+	grypeDB "github.com/anchore/grype/grype/db/v4"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vulnerability"
@@ -39,6 +39,10 @@ func (d *mockMetadataStore) GetVulnerabilityMetadata(id, recordSource string) (*
 	return d.data[id][recordSource], nil
 }
 
+func (d *mockMetadataStore) GetAllVulnerabilityMetadata() (*[]grypeDB.VulnerabilityMetadata, error) {
+	return nil, nil
+}
+
 func TestAboveAllowableSeverity(t *testing.T) {
 	thePkg := pkg.Package{
 		ID:      pkg.ID(uuid.NewString()),
